@@ -1,21 +1,8 @@
 /*
- *   Copyright (C) 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library/Lesser General Public License
- *   version 2, or (at your option) any later version, as published by the
- *   Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library/Lesser General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "plasmaappletitemmodel_p.h"
 
@@ -230,7 +217,7 @@ PlasmaAppletItemModel::PlasmaAppletItemModel(QObject *parent)
     : QStandardItemModel(parent)
     , m_startupCompleted(false)
 {
-    connect(KSycoca::self(), SIGNAL(databaseChanged(QStringList)), this, SLOT(populateModel(QStringList)));
+    connect(KSycoca::self(), QOverload<>::of(&KSycoca::databaseChanged), this, &PlasmaAppletItemModel::populateModel);
 
     setSortRole(Qt::DisplayRole);
 }
@@ -253,12 +240,8 @@ QHash<int, QByteArray> PlasmaAppletItemModel::roleNames() const
     return newRoleNames;
 }
 
-void PlasmaAppletItemModel::populateModel(const QStringList &whatChanged)
+void PlasmaAppletItemModel::populateModel()
 {
-    if (!whatChanged.isEmpty() && !whatChanged.contains(QLatin1String("services"))) {
-        return;
-    }
-
     clear();
 
     auto filter = [this](const KPluginMetaData &plugin) -> bool {
