@@ -1,24 +1,10 @@
 /*
- * Copyright © 2006-2007 Fredrik Höglund <fredrik@kde.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2 or at your option version 3 as published
- * by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2006-2007 Fredrik Höglund <fredrik@kde.org>
 
-#ifndef CURSORTHEME_H
-#define CURSORTHEME_H
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only
+*/
+
+#pragma once
 
 #include <QHash>
 #include <QPixmap>
@@ -197,5 +183,3 @@ void CursorTheme::setName(const QString &name)
     m_name = name;
     m_hash = qHash(name);
 }
-
-#endif // CURSORTHEME_H
