@@ -1,32 +1,20 @@
-/* This file is part of the KDE Project
-   Copyright (c) 2014 Marco Martin <mart@kde.org>
-   Copyright (c) 2014 Vishesh Handa <me@vhanda.in>
-   Copyright (c) 2019 Cyril Rossi <cyril.rossi@enioka.com>
-   Copyright (c) 2021 Benjamin Port <benjamin.port@enioka.com>
+/*
+    SPDX-FileCopyrightText: 2014 Marco Martin <mart@kde.org>
+    SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
+    SPDX-FileCopyrightText: 2019 Cyril Rossi <cyril.rossi@enioka.com>
+    SPDX-FileCopyrightText: 2021 Benjamin Port <benjamin.port@enioka.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kcm.h"
+#include "../../startkde/plasmaautostart/plasmaautostart.h"
 #include "../kcms-common_p.h"
 #include "config-kcm.h"
 #include "config-workspace.h"
 #include "krdb.h"
 
 #include <KAboutData>
-#include <KAutostart>
 #include <KDialogJobUiDelegate>
 #include <KIO/ApplicationLauncherJob>
 #include <KIconLoader>
@@ -51,11 +39,15 @@
 
 #include <X11/Xlib.h>
 
+#include <KNSCore/EntryInternal>
+#include <QFileInfo>
 #include <updatelaunchenvjob.h>
 
 #include "lookandfeeldata.h"
 #include "lookandfeelsettings.h"
 
+#include "../colors/colorsapplicator.h"
+
 #ifdef HAVE_XCURSOR
 #include "../cursortheme/xcursor/xcursortheme.h"
 #include <X11/Xcursor/Xcursor.h>
@@ -68,8 +60,8 @@
 KCMLookandFeel::KCMLookandFeel(QObject *parent, const QVariantList &args)
     : KQuickAddons::ManagedConfigModule(parent, args)
     , m_data(new LookAndFeelData(this))
-    , m_config(QStringLiteral("kdeglobals"))
-    , m_configGroup(m_config.group("KDE"))
+    , m_config(KSharedConfig::openConfig(QStringLiteral("kdeglobals"), KConfig::FullConfig))
+    , m_configGroup(m_config->group("KDE"))
     , m_applyColors(true)
     , m_applyWidgetStyle(true)
     , m_applyIcons(true)
@@ -115,9 +107,27 @@ KCMLookandFeel::~KCMLookandFeel()
 {
 }
 
-void KCMLookandFeel::reloadModel()
+void KCMLookandFeel::knsEntryChanged(KNSCore::EntryWrapper *wrapper)
 {
-    loadModel();
+    if (!wrapper) {
+        return;
+    }
+    const KNSCore::EntryInternal entry = wrapper->entry();
+    auto removeItemFromModel = [&entry, this]() {
+        const QString guessedPluginId = QFileInfo(entry.uninstalledFiles().constFirst()).fileName();
+        const int index = pluginIndex(guessedPluginId);
+        if (index != -1) {
+            m_model->removeRows(index, 1);
+        }
+    };
+    if (entry.status() == KNS3::Entry::Deleted && !entry.uninstalledFiles().isEmpty()) {
+        removeItemFromModel();
+    } else if (entry.status() == KNS3::Entry::Installed && !entry.installedFiles().isEmpty()) {
+        removeItemFromModel(); // In case we updated it we don't want to have it in twice
+        KPackage::Package pkg = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/LookAndFeel"));
+        pkg.setPath(entry.installedFiles().constFirst());
+        addKPackageToModel(pkg);
+    }
 }
 
 QStandardItemModel *KCMLookandFeel::lookAndFeelModel() const
@@ -185,60 +195,65 @@ void KCMLookandFeel::loadModel()
     });
 
     for (const KPackage::Package &pkg : pkgs) {
-        if (!pkg.metadata().isValid()) {
-            continue;
-        }
-        QStandardItem *row = new QStandardItem(pkg.metadata().name());
-        row->setData(pkg.metadata().pluginId(), PluginNameRole);
-        row->setData(pkg.metadata().description(), DescriptionRole);
-        row->setData(pkg.filePath("preview"), ScreenshotRole);
-        row->setData(pkg.filePath("fullscreenpreview"), FullScreenPreviewRole);
-
-        // What the package provides
-        row->setData(!pkg.filePath("splashmainscript").isEmpty(), HasSplashRole);
-        row->setData(!pkg.filePath("lockscreenmainscript").isEmpty(), HasLockScreenRole);
-        row->setData(!pkg.filePath("runcommandmainscript").isEmpty(), HasRunCommandRole);
-        row->setData(!pkg.filePath("logoutmainscript").isEmpty(), HasLogoutRole);
-
-        if (!pkg.filePath("defaults").isEmpty()) {
-            KSharedConfigPtr conf = KSharedConfig::openConfig(pkg.filePath("defaults"));
-            KConfigGroup cg(conf, "kdeglobals");
-            cg = KConfigGroup(&cg, "General");
-            bool hasColors = !cg.readEntry("ColorScheme", QString()).isEmpty();
-            if (!hasColors) {
-                hasColors = !pkg.filePath("colors").isEmpty();
-            }
-            row->setData(hasColors, HasColorsRole);
-            cg = KConfigGroup(&cg, "KDE");
-            row->setData(!cg.readEntry("widgetStyle", QString()).isEmpty(), HasWidgetStyleRole);
-            cg = KConfigGroup(conf, "kdeglobals");
-            cg = KConfigGroup(&cg, "Icons");
-            row->setData(!cg.readEntry("Theme", QString()).isEmpty(), HasIconsRole);
-
-            cg = KConfigGroup(conf, "kdeglobals");
-            cg = KConfigGroup(&cg, "Theme");
-            row->setData(!cg.readEntry("name", QString()).isEmpty(), HasPlasmaThemeRole);
-
-            cg = KConfigGroup(conf, "kcminputrc");
-            cg = KConfigGroup(&cg, "Mouse");
-            row->setData(!cg.readEntry("cursorTheme", QString()).isEmpty(), HasCursorsRole);
-
-            cg = KConfigGroup(conf, "kwinrc");
-            cg = KConfigGroup(&cg, "WindowSwitcher");
-            row->setData(!cg.readEntry("LayoutName", QString()).isEmpty(), HasWindowSwitcherRole);
-
-            cg = KConfigGroup(conf, "kwinrc");
-            cg = KConfigGroup(&cg, "DesktopSwitcher");
-            row->setData(!cg.readEntry("LayoutName", QString()).isEmpty(), HasDesktopSwitcherRole);
-        }
-
-        m_model->appendRow(row);
+        addKPackageToModel(pkg);
     }
 
     // Model has been cleared so pretend the selected look and fell changed to force view update
     emit lookAndFeelSettings()->lookAndFeelPackageChanged();
 }
 
+void KCMLookandFeel::addKPackageToModel(const KPackage::Package &pkg)
+{
+    if (!pkg.metadata().isValid()) {
+        return;
+    }
+    QStandardItem *row = new QStandardItem(pkg.metadata().name());
+    row->setData(pkg.metadata().pluginId(), PluginNameRole);
+    row->setData(pkg.metadata().description(), DescriptionRole);
+    row->setData(pkg.filePath("preview"), ScreenshotRole);
+    row->setData(pkg.filePath("fullscreenpreview"), FullScreenPreviewRole);
+
+    // What the package provides
+    row->setData(!pkg.filePath("splashmainscript").isEmpty(), HasSplashRole);
+    row->setData(!pkg.filePath("lockscreenmainscript").isEmpty(), HasLockScreenRole);
+    row->setData(!pkg.filePath("runcommandmainscript").isEmpty(), HasRunCommandRole);
+    row->setData(!pkg.filePath("logoutmainscript").isEmpty(), HasLogoutRole);
+
+    if (!pkg.filePath("defaults").isEmpty()) {
+        KSharedConfigPtr conf = KSharedConfig::openConfig(pkg.filePath("defaults"));
+        KConfigGroup cg(conf, "kdeglobals");
+        cg = KConfigGroup(&cg, "General");
+        bool hasColors = !cg.readEntry("ColorScheme", QString()).isEmpty();
+        if (!hasColors) {
+            hasColors = !pkg.filePath("colors").isEmpty();
+        }
+        row->setData(hasColors, HasColorsRole);
+        cg = KConfigGroup(&cg, "KDE");
+        row->setData(!cg.readEntry("widgetStyle", QString()).isEmpty(), HasWidgetStyleRole);
+        cg = KConfigGroup(conf, "kdeglobals");
+        cg = KConfigGroup(&cg, "Icons");
+        row->setData(!cg.readEntry("Theme", QString()).isEmpty(), HasIconsRole);
+
+        cg = KConfigGroup(conf, "kdeglobals");
+        cg = KConfigGroup(&cg, "Theme");
+        row->setData(!cg.readEntry("name", QString()).isEmpty(), HasPlasmaThemeRole);
+
+        cg = KConfigGroup(conf, "kcminputrc");
+        cg = KConfigGroup(&cg, "Mouse");
+        row->setData(!cg.readEntry("cursorTheme", QString()).isEmpty(), HasCursorsRole);
+
+        cg = KConfigGroup(conf, "kwinrc");
+        cg = KConfigGroup(&cg, "WindowSwitcher");
+        row->setData(!cg.readEntry("LayoutName", QString()).isEmpty(), HasWindowSwitcherRole);
+
+        cg = KConfigGroup(conf, "kwinrc");
+        cg = KConfigGroup(&cg, "DesktopSwitcher");
+        row->setData(!cg.readEntry("LayoutName", QString()).isEmpty(), HasDesktopSwitcherRole);
+    }
+
+    m_model->appendRow(row);
+}
+
 bool KCMLookandFeel::isSaveNeeded() const
 {
     return m_resetDefaultLayout || lookAndFeelSettings()->isSaveNeeded();
@@ -366,6 +381,18 @@ void KCMLookandFeel::save()
             setDesktopSwitcher(cg.readEntry("LayoutName", QString()));
         }
 
+        if (m_applyWindowPlacement) {
+            cg = KConfigGroup(conf, "kwinrc");
+            cg = KConfigGroup(&cg, "Windows");
+            setWindowPlacement(cg.readEntry("Placement", QStringLiteral("Smart")));
+        }
+
+        if (m_applyShellPackage) {
+            cg = KConfigGroup(conf, "plasmashellrc");
+            cg = KConfigGroup(&cg, "Shell");
+            setShellPackage(cg.readEntry("ShellPackage", QString()));
+        }
+
         if (m_applyWindowDecoration) {
             cg = KConfigGroup(conf, "kwinrc");
             cg = KConfigGroup(&cg, "org.kde.kdecoration2");
@@ -378,11 +405,17 @@ void KCMLookandFeel::save()
         }
 
         // Reload KWin if something changed, but only once.
-        if (m_applyWindowSwitcher || m_applyDesktopSwitcher || m_applyWindowDecoration) {
+        if (m_applyWindowSwitcher || m_applyDesktopSwitcher || m_applyWindowDecoration || m_applyWindowPlacement) {
             QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/KWin"), QStringLiteral("org.kde.KWin"), QStringLiteral("reloadConfig"));
             QDBusConnection::sessionBus().send(message);
         }
 
+        if (m_plasmashellChanged) {
+            QDBusMessage message =
+                QDBusMessage::createSignal(QStringLiteral("/PlasmaShell"), QStringLiteral("org.kde.PlasmaShell"), QStringLiteral("refreshCurrentShell"));
+            QDBusConnection::sessionBus().send(message);
+        }
+
         // autostart
         if (m_resetDefaultLayout) {
             // remove all the old package to autostart
@@ -394,7 +427,7 @@ void KCMLookandFeel::save()
                 if (qEnvironmentVariableIsSet("KDE_FULL_SESSION")) {
                     for (const QString &serviceFile : autostartServices) {
                         KService service(serviceFile + QStringLiteral(".desktop"));
-                        KAutostart as(serviceFile);
+                        PlasmaAutostart as(serviceFile);
                         as.setAutostarts(false);
                         // FIXME: quite ugly way to stop things, and what about non KDE things?
                         QProcess::startDetached(QStringLiteral("kquitapp5"),
@@ -409,7 +442,7 @@ void KCMLookandFeel::save()
 
                 for (const QString &serviceFile : autostartServices) {
                     KService::Ptr service{new KService(serviceFile + QStringLiteral(".desktop"))};
-                    KAutostart as(serviceFile);
+                    PlasmaAutostart as(serviceFile);
                     as.setCommand(service->exec());
                     as.setAutostarts(true);
                     if (qEnvironmentVariableIsSet("KDE_FULL_SESSION")) {
@@ -481,18 +514,17 @@ void KCMLookandFeel::setColors(const QString &scheme, const QString &colorFile)
         return;
     }
 
-    KSharedConfigPtr conf = KSharedConfig::openConfig(colorFile, KSharedConfig::CascadeConfig);
-    for (const QString &grp : conf->groupList()) {
-        KConfigGroup cg(conf, grp);
-        KConfigGroup cg2(&m_config, grp);
-        cg.copyTo(&cg2, KConfig::Notify);
-    }
-
     KConfig configDefault(configDefaults("kdeglobals"));
-    writeNewDefaults(m_config, configDefault, QStringLiteral("General"), QStringLiteral("ColorScheme"), scheme, KConfig::Notify);
-    m_config.sync();
-    configDefault.sync();
-    notifyKcmChange(GlobalChangeType::PaletteChanged);
+
+    auto set = [this]() {
+        m_config->group("General").writeEntry("AccentColor", QColor());
+        m_config->group("General").deleteEntry("AccentColor", KConfig::Notify);
+    };
+
+    set();
+    writeNewDefaults(*m_config, configDefault, QStringLiteral("General"), QStringLiteral("ColorScheme"), scheme, KConfig::Notify);
+    applyScheme(colorFile, m_config.data(), KConfig::Notify);
+    set();
 }
 
 void KCMLookandFeel::setIcons(const QString &theme)
@@ -531,8 +563,8 @@ void KCMLookandFeel::setCursorTheme(const QString themeName)
     // in previous versions the Xfixes code wasn't enabled due to a bug in the
     // build system (freedesktop bug #975).
 #if defined(HAVE_XFIXES) && XFIXES_MAJOR >= 2 && XCURSOR_LIB_VERSION >= 10105
-    KConfig config(QStringLiteral("kcminputrc"));
-    KConfigGroup cg(&config, QStringLiteral("Mouse"));
+    KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kcminputrc"));
+    KConfigGroup cg(config, QStringLiteral("Mouse"));
     const int cursorSize = cg.readEntry("cursorSize", 24);
 
     QDir themeDir = cursorThemeDir(themeName, 0);
@@ -678,8 +710,8 @@ void KCMLookandFeel::setSplashScreen(const QString &theme)
         return;
     }
 
-    KConfig config(QStringLiteral("ksplashrc"));
-    KConfigGroup cg(&config, QStringLiteral("KSplash"));
+    KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("ksplashrc"));
+    KConfigGroup cg(config, QStringLiteral("KSplash"));
 
     KConfig configDefault(configDefaults(QStringLiteral("ksplashrc")));
     KConfigGroup cgd(&configDefault, QStringLiteral("KSplash"));
@@ -712,8 +744,8 @@ void KCMLookandFeel::setDesktopSwitcher(const QString &theme)
         return;
     }
 
-    KConfig config(QStringLiteral("kwinrc"));
-    KConfigGroup cg(&config, QStringLiteral("TabBox"));
+    KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kwinrc"));
+    KConfigGroup cg(config, QStringLiteral("TabBox"));
 
     KConfig configDefault(configDefaults(QStringLiteral("kwinrc")));
     KConfigGroup cgd(&configDefault, QStringLiteral("TabBox"));
@@ -721,23 +753,38 @@ void KCMLookandFeel::setDesktopSwitcher(const QString &theme)
     writeNewDefaults(cg, cgd, QStringLiteral("DesktopListLayout"), theme);
 }
 
+void KCMLookandFeel::setWindowPlacement(const QString &value)
+{
+    if (value.isEmpty()) {
+        return;
+    }
+
+    writeNewDefaults(QStringLiteral("kwinrc"), QStringLiteral("Windows"), QStringLiteral("Placement"), value);
+}
+
+void KCMLookandFeel::setShellPackage(const QString &value)
+{
+    if (value.isEmpty()) {
+        return;
+    }
+
+    writeNewDefaults(QStringLiteral("plasmashellrc"), QStringLiteral("Shell"), QStringLiteral("ShellPackage"), value);
+    m_plasmashellChanged = true;
+}
+
 void KCMLookandFeel::setWindowDecoration(const QString &library, const QString &theme)
 {
     if (library.isEmpty()) {
         return;
     }
 
-    KConfig config(QStringLiteral("kwinrc"));
-    KConfigGroup cg(&config, QStringLiteral("org.kde.kdecoration2"));
+    KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kwinrc"));
+    KConfigGroup cg(config, QStringLiteral("org.kde.kdecoration2"));
 
     KConfig configDefault(configDefaults(QStringLiteral("kwinrc")));
     KConfigGroup cgd(&configDefault, QStringLiteral("org.kde.kdecoration2"));
     writeNewDefaults(cg, cgd, QStringLiteral("library"), library);
     writeNewDefaults(cg, cgd, QStringLiteral("theme"), theme, KConfig::Notify);
-
-    // Reload KWin.
-    QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/KWin"), QStringLiteral("org.kde.KWin"), QStringLiteral("reloadConfig"));
-    QDBusConnection::sessionBus().send(message);
 }
 
 void KCMLookandFeel::setResetDefaultLayout(bool reset)
@@ -761,8 +808,8 @@ void KCMLookandFeel::writeNewDefaults(const QString &filename,
                                       const QString &value,
                                       KConfig::WriteConfigFlags writeFlags)
 {
-    KConfig config(filename);
-    KConfigGroup cg(&config, group);
+    KSharedConfigPtr config = KSharedConfig::openConfig(filename);
+    KConfigGroup cg(config, group);
 
     KConfig configDefault(configDefaults(filename));
     KConfigGroup cgd(&configDefault, group);
