@@ -1,20 +1,8 @@
 /*
- *   Copyright (C) 2007 Teemu Rytilahti <tpr@iki.fi>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License version 2 as
- *   published by the Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007 Teemu Rytilahti <tpr@iki.fi>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "webshortcutrunner.h"
 
@@ -75,7 +63,8 @@ void WebshortcutRunner::loadSyntaxes()
 
 void WebshortcutRunner::configurePrivateBrowsingActions()
 {
-    clearActions();
+    qDeleteAll(m_match.actions());
+    m_match.setActions({});
     const QString browserFile = KSharedConfig::openConfig(QStringLiteral("kdeglobals"))->group("General").readEntry("BrowserApplication");
     KService::Ptr service;
     if (!browserFile.isEmpty()) {
@@ -174,6 +163,6 @@ void WebshortcutRunner::run(const Plasma::RunnerContext &context, const Plasma::
     }
 }
 
-K_EXPORT_PLASMA_RUNNER_WITH_JSON(WebshortcutRunner, "plasma-runner-webshortcuts.json")
+K_PLUGIN_CLASS_WITH_JSON(WebshortcutRunner, "plasma-runner-webshortcuts.json")
 
 #include "webshortcutrunner.moc"
