@@ -1,24 +1,10 @@
 /*
- *   Copyright 2011-2012 by Sebastian Kügler <sebas@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2011-2012 Sebastian Kügler <sebas@kde.org>
 
-#ifndef CONFIGGROUP_H
-#define CONFIGGROUP_H
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
+#pragma once
 
 #include <QJSValue>
 #include <QObject>
@@ -70,5 +56,3 @@ private:
 private Q_SLOTS:
     void sync();
 };
-
-#endif
